==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/arraycheck/Array2ndDimensionSymbol.h <==
// class soot.jimple.toolkits.annotation.arraycheck.Array2ndDimensionSymbol

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 30723d7acacdee64 soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method$getVar$ca7a93fb83224996(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *);
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method_info$getVar$ca7a93fb83224996;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method$v$3ce4a6d96c45ae52(_jc_env *, struct _jc_java_lang_Object$object *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*getVar$ca7a93fb83224996)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vmethods	soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_refs {
	struct _jc_java_lang_Object$object	*var;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_refs	soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/arraycheck/Array2ndDimensionSymbol.h <==
// class soot.jimple.toolkits.annotation.arraycheck.Array2ndDimensionSymbol

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 30723d7acacdee64 soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method$getVar$ca7a93fb83224996(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method_info$getVar$ca7a93fb83224996;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$method$v$3ce4a6d96c45ae52(_jc_env *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*getVar$ca7a93fb83224996)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vmethods	soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_refs {
	struct _jc_java_lang_Object$object	*var;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_refs	soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_Array2ndDimensionSymbol_H_ */
